API - 常用工具箱
========================

.. image:: my_figs/mytools.ico 
.. automodule:: chat.mytools

.. autosummary::

   get_mac_address
   get_hostname
   get_ip_address
   get_current_function_name
   Walk
   time_me
   get_current_time
   random_item
   file_replace
   read_excel
   set_excel_style
   write_excel
   generate_dict
   waitting
   
获取Mac地址
------------------------
.. autofunction:: get_mac_address

获取主机名
------------------------
.. autofunction:: get_hostname

获取IP地址
------------------------
.. autofunction:: get_ip_address

获取当前运行函数名
------------------------
.. autofunction:: get_current_function_name

遍历目录进行批处理
------------------------
.. autofunction:: Walk

程序时间性能分析
------------------------
.. autofunction:: time_me

获取当前时间
------------------------
.. autofunction:: get_current_time

列表随机元素
------------------------
.. autofunction:: random_item

文件替换
------------------------
.. autofunction:: file_replace

读取excel
------------------------
.. autofunction:: read_excel

设置excel样式
------------------------
.. autofunction:: set_excel_style

写入excel
------------------------
.. autofunction:: write_excel

生成词典
------------------------
.. autofunction:: generate_dict

显示等待中
------------------------
.. autofunction:: waitting
